@@ -150,7 +150,7 @@ void KSMainWindow::init()
     mDialogButtonBox->addButton(mSendToButton, QDialogButtonBox::ActionRole);
 
     mClipboardButton->setDefaultAction(KStandardAction::copy(this, SLOT(sendToClipboard()), this));
-    mClipboardButton->setText(i18n("Copy To Clipboard"));
+    mClipboardButton->setText(i18n("Copy to Clipboard"));
     mClipboardButton->setToolTip(i18n("Copy the current screenshot image to the clipboard."));
     mClipboardButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     mDialogButtonBox->addButton(mClipboardButton, QDialogButtonBox::ActionRole);
@@ -239,7 +239,9 @@ void KSMainWindow::setDefaultSaveAction()
 {
     switch (SpectacleConfig::instance()->lastUsedSaveMode()) {
     case SaveMode::SaveAs:
+    default:
         mSaveButton->setDefaultAction(mSaveAsAction);
+        mSaveButton->setText(i18n("Save As..."));
         break;
     case SaveMode::Save:
         mSaveButton->setDefaultAction(mSaveAction);
@@ -274,7 +276,7 @@ void KSMainWindow::setScreenshotAndShow(const QPixmap &pixmap)
     mKSWidget->setScreenshotPixmap(pixmap);
     mExportMenu->imageUpdated();
 
-    setWindowTitle(i18nc("Unsaved Screenshot", "Unsaved[*]"));
+    setWindowTitle(i18nc("@title:window Unsaved Screenshot", "Unsaved[*]"));
     setWindowModified(true);
 
     show();
@@ -295,22 +297,30 @@ void KSMainWindow::showPrintDialog()
 
 void KSMainWindow::openScreenshotsFolder()
 {
-    // Highlight last screenshot in file manager if user saved at least once,
-    // or open default directory as determined by save button
-    QUrl location = ExportManager::instance()->lastSavePath();
-    if (!ExportManager::instance()->isFileExists(location)) {
-        switch(SpectacleConfig::instance()->lastUsedSaveMode()) {
-        case SaveMode::Save:
-            location = QUrl::fromLocalFile(ExportManager::instance()->saveLocation() + QStringLiteral("/"));
-            break;
-        case SaveMode::SaveAs:
-            location = SpectacleConfig::instance()->lastSaveAsLocation();  // already has a "/" at the end
-            break;
+    // Highlight last screenshot in file manager if user saved at least once ever 
+    // (since last save and saveas file names are stored in spectaclerc), otherwise, 
+    //   if in save mode, open default save location from configure > save > location
+    //   if in save as mode, open last save as files location
+    // failsafe for either option is default save location from configure > save > location
+    SpectacleConfig *cfgManager = SpectacleConfig::instance();
+    ExportManager *exportManager = ExportManager::instance();
+    QUrl location;
+    
+    switch(cfgManager->lastUsedSaveMode()) {
+    case SaveMode::Save:
+        location = cfgManager->lastSaveFile();
+        if (!exportManager->isFileExists(location)) {
+            location = QUrl(cfgManager->defaultSaveLocation());
         }
-        if (!ExportManager::instance()->isFileExists(location)) {
-            location = QUrl(QStandardPaths::writableLocation(QStandardPaths::PicturesLocation) + QStringLiteral("/"));
+        break;
+    case SaveMode::SaveAs:
+        location = cfgManager->lastSaveAsFile();  // already has a "/" at the end
+        if (!exportManager->isFileExists(location)) {
+            location = cfgManager->lastSaveAsLocation();
         }
+        break;
     }
+
     KIO::highlightInFileManager({location});
 }
 
@@ -339,6 +349,9 @@ void KSMainWindow::showInlineMessage(const QString& message, const KMessageWidge
     case KMessageWidget::Error:
         mMessageWidget->setIcon(QIcon::fromTheme(QStringLiteral("dialog-error")));
         break;
+    case KMessageWidget::Warning:
+        mMessageWidget->setIcon(QIcon::fromTheme(QStringLiteral("dialog-warning")));
+        break;
     case KMessageWidget::Positive:
         mMessageWidget->setIcon(QIcon::fromTheme(QStringLiteral("dialog-ok-apply")));
         break;
