@@ -31,12 +31,12 @@ class QuickEditor : public QObject
     explicit QuickEditor(const QPixmap &pixmap, QObject *parent = nullptr);
     virtual ~QuickEditor();
 
-    signals:
+    Q_SIGNALS:
 
     void grabDone(const QPixmap &pixmap, const QRect &cropRegion);
     void grabCancelled();
 
-    private slots:
+    private Q_SLOTS:
 
     void acceptImageHandler(int x, int y, int width, int height);
 
@@ -45,8 +45,8 @@ class QuickEditor : public QObject
     struct ImageStore;
     ImageStore *mImageStore;
 
-    struct QuickEditorPrivate;
-    Q_DECLARE_PRIVATE(QuickEditor);
+    class QuickEditorPrivate;
+    Q_DECLARE_PRIVATE(QuickEditor)
     QuickEditorPrivate *d_ptr;
 };
 
